@@ -1,10 +1,8 @@
 package Scaffold::Uaf::Manager;
 
-use strict;
-use warnings;
-
 our $VERSION = '0.02';
 
+use 5.8.8;
 use Try::Tiny;
 
 use Scaffold::Class
@@ -139,11 +137,13 @@ Checks to see if the current session is authenticated, redirects as needed.
  Scaffold::Constants
  Scaffold::Engine
  Scaffold::Handler
+ Scaffold::Handler::Default
  Scaffold::Handler::Favicon
  Scaffold::Handler::Robots
  Scaffold::Handler::Static
  Scaffold::Lockmgr
  Scaffold::Lockmgr::KeyedMutex
+ Scaffold::Lockmgr::UnixMutex
  Scaffold::Plugins
  Scaffold::Render
  Scaffold::Render::Default
